# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'settlement_date': 'date',
        'settlement_period': 'int',
        'start_time': 'datetime',
        'created_date_time': 'datetime',
        'system_sell_price': 'float',
        'system_buy_price': 'float',
        'bsad_defaulted': 'bool',
        'price_derivation_code': 'str',
        'reserve_scarcity_price': 'float',
        'net_imbalance_volume': 'float',
        'sell_price_adjustment': 'float',
        'buy_price_adjustment': 'float',
        'replacement_price': 'float',
        'replacement_price_reference_volume': 'float',
        'total_accepted_offer_volume': 'float',
        'total_accepted_bid_volume': 'float',
        'total_adjustment_sell_volume': 'float',
        'total_adjustment_buy_volume': 'float',
        'total_system_tagged_accepted_offer_volume': 'float',
        'total_system_tagged_accepted_bid_volume': 'float',
        'total_system_tagged_adjustment_sell_volume': 'float',
        'total_system_tagged_adjustment_buy_volume': 'float'
    }

    attribute_map = {
        'settlement_date': 'settlementDate',
        'settlement_period': 'settlementPeriod',
        'start_time': 'startTime',
        'created_date_time': 'createdDateTime',
        'system_sell_price': 'systemSellPrice',
        'system_buy_price': 'systemBuyPrice',
        'bsad_defaulted': 'bsadDefaulted',
        'price_derivation_code': 'priceDerivationCode',
        'reserve_scarcity_price': 'reserveScarcityPrice',
        'net_imbalance_volume': 'netImbalanceVolume',
        'sell_price_adjustment': 'sellPriceAdjustment',
        'buy_price_adjustment': 'buyPriceAdjustment',
        'replacement_price': 'replacementPrice',
        'replacement_price_reference_volume': 'replacementPriceReferenceVolume',
        'total_accepted_offer_volume': 'totalAcceptedOfferVolume',
        'total_accepted_bid_volume': 'totalAcceptedBidVolume',
        'total_adjustment_sell_volume': 'totalAdjustmentSellVolume',
        'total_adjustment_buy_volume': 'totalAdjustmentBuyVolume',
        'total_system_tagged_accepted_offer_volume': 'totalSystemTaggedAcceptedOfferVolume',
        'total_system_tagged_accepted_bid_volume': 'totalSystemTaggedAcceptedBidVolume',
        'total_system_tagged_adjustment_sell_volume': 'totalSystemTaggedAdjustmentSellVolume',
        'total_system_tagged_adjustment_buy_volume': 'totalSystemTaggedAdjustmentBuyVolume'
    }

    def __init__(self, settlement_date=None, settlement_period=None, start_time=None, created_date_time=None, system_sell_price=None, system_buy_price=None, bsad_defaulted=None, price_derivation_code=None, reserve_scarcity_price=None, net_imbalance_volume=None, sell_price_adjustment=None, buy_price_adjustment=None, replacement_price=None, replacement_price_reference_volume=None, total_accepted_offer_volume=None, total_accepted_bid_volume=None, total_adjustment_sell_volume=None, total_adjustment_buy_volume=None, total_system_tagged_accepted_offer_volume=None, total_system_tagged_accepted_bid_volume=None, total_system_tagged_adjustment_sell_volume=None, total_system_tagged_adjustment_buy_volume=None):  # noqa: E501
        """InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse - a model defined in Swagger"""  # noqa: E501
        self._settlement_date = None
        self._settlement_period = None
        self._start_time = None
        self._created_date_time = None
        self._system_sell_price = None
        self._system_buy_price = None
        self._bsad_defaulted = None
        self._price_derivation_code = None
        self._reserve_scarcity_price = None
        self._net_imbalance_volume = None
        self._sell_price_adjustment = None
        self._buy_price_adjustment = None
        self._replacement_price = None
        self._replacement_price_reference_volume = None
        self._total_accepted_offer_volume = None
        self._total_accepted_bid_volume = None
        self._total_adjustment_sell_volume = None
        self._total_adjustment_buy_volume = None
        self._total_system_tagged_accepted_offer_volume = None
        self._total_system_tagged_accepted_bid_volume = None
        self._total_system_tagged_adjustment_sell_volume = None
        self._total_system_tagged_adjustment_buy_volume = None
        self.discriminator = None
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period is not None:
            self.settlement_period = settlement_period
        if start_time is not None:
            self.start_time = start_time
        if created_date_time is not None:
            self.created_date_time = created_date_time
        if system_sell_price is not None:
            self.system_sell_price = system_sell_price
        if system_buy_price is not None:
            self.system_buy_price = system_buy_price
        if bsad_defaulted is not None:
            self.bsad_defaulted = bsad_defaulted
        if price_derivation_code is not None:
            self.price_derivation_code = price_derivation_code
        if reserve_scarcity_price is not None:
            self.reserve_scarcity_price = reserve_scarcity_price
        if net_imbalance_volume is not None:
            self.net_imbalance_volume = net_imbalance_volume
        if sell_price_adjustment is not None:
            self.sell_price_adjustment = sell_price_adjustment
        if buy_price_adjustment is not None:
            self.buy_price_adjustment = buy_price_adjustment
        if replacement_price is not None:
            self.replacement_price = replacement_price
        if replacement_price_reference_volume is not None:
            self.replacement_price_reference_volume = replacement_price_reference_volume
        if total_accepted_offer_volume is not None:
            self.total_accepted_offer_volume = total_accepted_offer_volume
        if total_accepted_bid_volume is not None:
            self.total_accepted_bid_volume = total_accepted_bid_volume
        if total_adjustment_sell_volume is not None:
            self.total_adjustment_sell_volume = total_adjustment_sell_volume
        if total_adjustment_buy_volume is not None:
            self.total_adjustment_buy_volume = total_adjustment_buy_volume
        if total_system_tagged_accepted_offer_volume is not None:
            self.total_system_tagged_accepted_offer_volume = total_system_tagged_accepted_offer_volume
        if total_system_tagged_accepted_bid_volume is not None:
            self.total_system_tagged_accepted_bid_volume = total_system_tagged_accepted_bid_volume
        if total_system_tagged_adjustment_sell_volume is not None:
            self.total_system_tagged_adjustment_sell_volume = total_system_tagged_adjustment_sell_volume
        if total_system_tagged_adjustment_buy_volume is not None:
            self.total_system_tagged_adjustment_buy_volume = total_system_tagged_adjustment_buy_volume

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period(self):
        """Gets the settlement_period of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The settlement_period of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period

    @settlement_period.setter
    def settlement_period(self, settlement_period):
        """Sets the settlement_period of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param settlement_period: The settlement_period of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: int
        """

        self._settlement_period = settlement_period

    @property
    def start_time(self):
        """Gets the start_time of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The start_time of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param start_time: The start_time of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def created_date_time(self):
        """Gets the created_date_time of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The created_date_time of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date_time

    @created_date_time.setter
    def created_date_time(self, created_date_time):
        """Sets the created_date_time of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param created_date_time: The created_date_time of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: datetime
        """

        self._created_date_time = created_date_time

    @property
    def system_sell_price(self):
        """Gets the system_sell_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The system_sell_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._system_sell_price

    @system_sell_price.setter
    def system_sell_price(self, system_sell_price):
        """Sets the system_sell_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param system_sell_price: The system_sell_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._system_sell_price = system_sell_price

    @property
    def system_buy_price(self):
        """Gets the system_buy_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The system_buy_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._system_buy_price

    @system_buy_price.setter
    def system_buy_price(self, system_buy_price):
        """Sets the system_buy_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param system_buy_price: The system_buy_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._system_buy_price = system_buy_price

    @property
    def bsad_defaulted(self):
        """Gets the bsad_defaulted of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The bsad_defaulted of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: bool
        """
        return self._bsad_defaulted

    @bsad_defaulted.setter
    def bsad_defaulted(self, bsad_defaulted):
        """Sets the bsad_defaulted of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param bsad_defaulted: The bsad_defaulted of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: bool
        """

        self._bsad_defaulted = bsad_defaulted

    @property
    def price_derivation_code(self):
        """Gets the price_derivation_code of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The price_derivation_code of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: str
        """
        return self._price_derivation_code

    @price_derivation_code.setter
    def price_derivation_code(self, price_derivation_code):
        """Sets the price_derivation_code of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param price_derivation_code: The price_derivation_code of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: str
        """

        self._price_derivation_code = price_derivation_code

    @property
    def reserve_scarcity_price(self):
        """Gets the reserve_scarcity_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The reserve_scarcity_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._reserve_scarcity_price

    @reserve_scarcity_price.setter
    def reserve_scarcity_price(self, reserve_scarcity_price):
        """Sets the reserve_scarcity_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param reserve_scarcity_price: The reserve_scarcity_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._reserve_scarcity_price = reserve_scarcity_price

    @property
    def net_imbalance_volume(self):
        """Gets the net_imbalance_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The net_imbalance_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._net_imbalance_volume

    @net_imbalance_volume.setter
    def net_imbalance_volume(self, net_imbalance_volume):
        """Sets the net_imbalance_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param net_imbalance_volume: The net_imbalance_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._net_imbalance_volume = net_imbalance_volume

    @property
    def sell_price_adjustment(self):
        """Gets the sell_price_adjustment of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The sell_price_adjustment of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._sell_price_adjustment

    @sell_price_adjustment.setter
    def sell_price_adjustment(self, sell_price_adjustment):
        """Sets the sell_price_adjustment of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param sell_price_adjustment: The sell_price_adjustment of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._sell_price_adjustment = sell_price_adjustment

    @property
    def buy_price_adjustment(self):
        """Gets the buy_price_adjustment of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The buy_price_adjustment of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._buy_price_adjustment

    @buy_price_adjustment.setter
    def buy_price_adjustment(self, buy_price_adjustment):
        """Sets the buy_price_adjustment of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param buy_price_adjustment: The buy_price_adjustment of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._buy_price_adjustment = buy_price_adjustment

    @property
    def replacement_price(self):
        """Gets the replacement_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The replacement_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._replacement_price

    @replacement_price.setter
    def replacement_price(self, replacement_price):
        """Sets the replacement_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param replacement_price: The replacement_price of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._replacement_price = replacement_price

    @property
    def replacement_price_reference_volume(self):
        """Gets the replacement_price_reference_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The replacement_price_reference_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._replacement_price_reference_volume

    @replacement_price_reference_volume.setter
    def replacement_price_reference_volume(self, replacement_price_reference_volume):
        """Sets the replacement_price_reference_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param replacement_price_reference_volume: The replacement_price_reference_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._replacement_price_reference_volume = replacement_price_reference_volume

    @property
    def total_accepted_offer_volume(self):
        """Gets the total_accepted_offer_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The total_accepted_offer_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_accepted_offer_volume

    @total_accepted_offer_volume.setter
    def total_accepted_offer_volume(self, total_accepted_offer_volume):
        """Sets the total_accepted_offer_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param total_accepted_offer_volume: The total_accepted_offer_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._total_accepted_offer_volume = total_accepted_offer_volume

    @property
    def total_accepted_bid_volume(self):
        """Gets the total_accepted_bid_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The total_accepted_bid_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_accepted_bid_volume

    @total_accepted_bid_volume.setter
    def total_accepted_bid_volume(self, total_accepted_bid_volume):
        """Sets the total_accepted_bid_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param total_accepted_bid_volume: The total_accepted_bid_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._total_accepted_bid_volume = total_accepted_bid_volume

    @property
    def total_adjustment_sell_volume(self):
        """Gets the total_adjustment_sell_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The total_adjustment_sell_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_adjustment_sell_volume

    @total_adjustment_sell_volume.setter
    def total_adjustment_sell_volume(self, total_adjustment_sell_volume):
        """Sets the total_adjustment_sell_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param total_adjustment_sell_volume: The total_adjustment_sell_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._total_adjustment_sell_volume = total_adjustment_sell_volume

    @property
    def total_adjustment_buy_volume(self):
        """Gets the total_adjustment_buy_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The total_adjustment_buy_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_adjustment_buy_volume

    @total_adjustment_buy_volume.setter
    def total_adjustment_buy_volume(self, total_adjustment_buy_volume):
        """Sets the total_adjustment_buy_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param total_adjustment_buy_volume: The total_adjustment_buy_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._total_adjustment_buy_volume = total_adjustment_buy_volume

    @property
    def total_system_tagged_accepted_offer_volume(self):
        """Gets the total_system_tagged_accepted_offer_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The total_system_tagged_accepted_offer_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_system_tagged_accepted_offer_volume

    @total_system_tagged_accepted_offer_volume.setter
    def total_system_tagged_accepted_offer_volume(self, total_system_tagged_accepted_offer_volume):
        """Sets the total_system_tagged_accepted_offer_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param total_system_tagged_accepted_offer_volume: The total_system_tagged_accepted_offer_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._total_system_tagged_accepted_offer_volume = total_system_tagged_accepted_offer_volume

    @property
    def total_system_tagged_accepted_bid_volume(self):
        """Gets the total_system_tagged_accepted_bid_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The total_system_tagged_accepted_bid_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_system_tagged_accepted_bid_volume

    @total_system_tagged_accepted_bid_volume.setter
    def total_system_tagged_accepted_bid_volume(self, total_system_tagged_accepted_bid_volume):
        """Sets the total_system_tagged_accepted_bid_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param total_system_tagged_accepted_bid_volume: The total_system_tagged_accepted_bid_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._total_system_tagged_accepted_bid_volume = total_system_tagged_accepted_bid_volume

    @property
    def total_system_tagged_adjustment_sell_volume(self):
        """Gets the total_system_tagged_adjustment_sell_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The total_system_tagged_adjustment_sell_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_system_tagged_adjustment_sell_volume

    @total_system_tagged_adjustment_sell_volume.setter
    def total_system_tagged_adjustment_sell_volume(self, total_system_tagged_adjustment_sell_volume):
        """Sets the total_system_tagged_adjustment_sell_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param total_system_tagged_adjustment_sell_volume: The total_system_tagged_adjustment_sell_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._total_system_tagged_adjustment_sell_volume = total_system_tagged_adjustment_sell_volume

    @property
    def total_system_tagged_adjustment_buy_volume(self):
        """Gets the total_system_tagged_adjustment_buy_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501


        :return: The total_system_tagged_adjustment_buy_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_system_tagged_adjustment_buy_volume

    @total_system_tagged_adjustment_buy_volume.setter
    def total_system_tagged_adjustment_buy_volume(self, total_system_tagged_adjustment_buy_volume):
        """Sets the total_system_tagged_adjustment_buy_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.


        :param total_system_tagged_adjustment_buy_volume: The total_system_tagged_adjustment_buy_volume of this InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse.  # noqa: E501
        :type: float
        """

        self._total_system_tagged_adjustment_buy_volume = total_system_tagged_adjustment_buy_volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesBalancingSettlementSystemPriceResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'mrid': 'str',
        'revision_number': 'int',
        'created_time': 'datetime',
        'publish_time': 'datetime',
        'url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'mrid': 'mrid',
        'revision_number': 'revisionNumber',
        'created_time': 'createdTime',
        'publish_time': 'publishTime',
        'url': 'url'
    }

    def __init__(self, id=None, mrid=None, revision_number=None, created_time=None, publish_time=None, url=None):  # noqa: E501
        """InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._mrid = None
        self._revision_number = None
        self._created_time = None
        self._publish_time = None
        self._url = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if mrid is not None:
            self.mrid = mrid
        if revision_number is not None:
            self.revision_number = revision_number
        if created_time is not None:
            self.created_time = created_time
        if publish_time is not None:
            self.publish_time = publish_time
        if url is not None:
            self.url = url

    @property
    def id(self):
        """Gets the id of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501


        :return: The id of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.


        :param id: The id of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def mrid(self):
        """Gets the mrid of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501


        :return: The mrid of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501
        :rtype: str
        """
        return self._mrid

    @mrid.setter
    def mrid(self, mrid):
        """Sets the mrid of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.


        :param mrid: The mrid of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501
        :type: str
        """

        self._mrid = mrid

    @property
    def revision_number(self):
        """Gets the revision_number of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501


        :return: The revision_number of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501
        :rtype: int
        """
        return self._revision_number

    @revision_number.setter
    def revision_number(self, revision_number):
        """Sets the revision_number of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.


        :param revision_number: The revision_number of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501
        :type: int
        """

        self._revision_number = revision_number

    @property
    def created_time(self):
        """Gets the created_time of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501


        :return: The created_time of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501
        :rtype: datetime
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.


        :param created_time: The created_time of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501
        :type: datetime
        """

        self._created_time = created_time

    @property
    def publish_time(self):
        """Gets the publish_time of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501


        :return: The publish_time of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501
        :rtype: datetime
        """
        return self._publish_time

    @publish_time.setter
    def publish_time(self, publish_time):
        """Sets the publish_time of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.


        :param publish_time: The publish_time of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501
        :type: datetime
        """

        self._publish_time = publish_time

    @property
    def url(self):
        """Gets the url of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501


        :return: The url of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.


        :param url: The url of this InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset': 'str',
        'm_rid': 'str',
        'revision_number': 'int',
        'publish_time': 'datetime',
        'publishing_period_commencing_time': 'datetime',
        'affected_dso': 'str',
        'demand_control_id': 'str',
        'instruction_sequence': 'int',
        'demand_control_event_flag': 'str',
        'time_from': 'datetime',
        'time_to': 'datetime',
        'volume': 'float',
        'system_management_action_flag': 'str',
        'amendment_flag': 'str'
    }

    attribute_map = {
        'dataset': 'dataset',
        'm_rid': 'mRID',
        'revision_number': 'revisionNumber',
        'publish_time': 'publishTime',
        'publishing_period_commencing_time': 'publishingPeriodCommencingTime',
        'affected_dso': 'affectedDso',
        'demand_control_id': 'demandControlId',
        'instruction_sequence': 'instructionSequence',
        'demand_control_event_flag': 'demandControlEventFlag',
        'time_from': 'timeFrom',
        'time_to': 'timeTo',
        'volume': 'volume',
        'system_management_action_flag': 'systemManagementActionFlag',
        'amendment_flag': 'amendmentFlag'
    }

    def __init__(self, dataset=None, m_rid=None, revision_number=None, publish_time=None, publishing_period_commencing_time=None, affected_dso=None, demand_control_id=None, instruction_sequence=None, demand_control_event_flag=None, time_from=None, time_to=None, volume=None, system_management_action_flag=None, amendment_flag=None):  # noqa: E501
        """InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow - a model defined in Swagger"""  # noqa: E501
        self._dataset = None
        self._m_rid = None
        self._revision_number = None
        self._publish_time = None
        self._publishing_period_commencing_time = None
        self._affected_dso = None
        self._demand_control_id = None
        self._instruction_sequence = None
        self._demand_control_event_flag = None
        self._time_from = None
        self._time_to = None
        self._volume = None
        self._system_management_action_flag = None
        self._amendment_flag = None
        self.discriminator = None
        if dataset is not None:
            self.dataset = dataset
        if m_rid is not None:
            self.m_rid = m_rid
        if revision_number is not None:
            self.revision_number = revision_number
        if publish_time is not None:
            self.publish_time = publish_time
        if publishing_period_commencing_time is not None:
            self.publishing_period_commencing_time = publishing_period_commencing_time
        if affected_dso is not None:
            self.affected_dso = affected_dso
        if demand_control_id is not None:
            self.demand_control_id = demand_control_id
        if instruction_sequence is not None:
            self.instruction_sequence = instruction_sequence
        if demand_control_event_flag is not None:
            self.demand_control_event_flag = demand_control_event_flag
        if time_from is not None:
            self.time_from = time_from
        if time_to is not None:
            self.time_to = time_to
        if volume is not None:
            self.volume = volume
        if system_management_action_flag is not None:
            self.system_management_action_flag = system_management_action_flag
        if amendment_flag is not None:
            self.amendment_flag = amendment_flag

    @property
    def dataset(self):
        """Gets the dataset of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The dataset of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param dataset: The dataset of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: str
        """

        self._dataset = dataset

    @property
    def m_rid(self):
        """Gets the m_rid of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The m_rid of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._m_rid

    @m_rid.setter
    def m_rid(self, m_rid):
        """Sets the m_rid of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param m_rid: The m_rid of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: str
        """

        self._m_rid = m_rid

    @property
    def revision_number(self):
        """Gets the revision_number of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The revision_number of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: int
        """
        return self._revision_number

    @revision_number.setter
    def revision_number(self, revision_number):
        """Sets the revision_number of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param revision_number: The revision_number of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: int
        """

        self._revision_number = revision_number

    @property
    def publish_time(self):
        """Gets the publish_time of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The publish_time of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: datetime
        """
        return self._publish_time

    @publish_time.setter
    def publish_time(self, publish_time):
        """Sets the publish_time of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param publish_time: The publish_time of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: datetime
        """

        self._publish_time = publish_time

    @property
    def publishing_period_commencing_time(self):
        """Gets the publishing_period_commencing_time of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The publishing_period_commencing_time of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: datetime
        """
        return self._publishing_period_commencing_time

    @publishing_period_commencing_time.setter
    def publishing_period_commencing_time(self, publishing_period_commencing_time):
        """Sets the publishing_period_commencing_time of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param publishing_period_commencing_time: The publishing_period_commencing_time of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: datetime
        """

        self._publishing_period_commencing_time = publishing_period_commencing_time

    @property
    def affected_dso(self):
        """Gets the affected_dso of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The affected_dso of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._affected_dso

    @affected_dso.setter
    def affected_dso(self, affected_dso):
        """Sets the affected_dso of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param affected_dso: The affected_dso of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: str
        """

        self._affected_dso = affected_dso

    @property
    def demand_control_id(self):
        """Gets the demand_control_id of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The demand_control_id of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._demand_control_id

    @demand_control_id.setter
    def demand_control_id(self, demand_control_id):
        """Sets the demand_control_id of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param demand_control_id: The demand_control_id of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: str
        """

        self._demand_control_id = demand_control_id

    @property
    def instruction_sequence(self):
        """Gets the instruction_sequence of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The instruction_sequence of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: int
        """
        return self._instruction_sequence

    @instruction_sequence.setter
    def instruction_sequence(self, instruction_sequence):
        """Sets the instruction_sequence of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param instruction_sequence: The instruction_sequence of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: int
        """

        self._instruction_sequence = instruction_sequence

    @property
    def demand_control_event_flag(self):
        """Gets the demand_control_event_flag of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The demand_control_event_flag of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._demand_control_event_flag

    @demand_control_event_flag.setter
    def demand_control_event_flag(self, demand_control_event_flag):
        """Sets the demand_control_event_flag of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param demand_control_event_flag: The demand_control_event_flag of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: str
        """

        self._demand_control_event_flag = demand_control_event_flag

    @property
    def time_from(self):
        """Gets the time_from of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The time_from of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: datetime
        """
        return self._time_from

    @time_from.setter
    def time_from(self, time_from):
        """Sets the time_from of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param time_from: The time_from of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: datetime
        """

        self._time_from = time_from

    @property
    def time_to(self):
        """Gets the time_to of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The time_to of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: datetime
        """
        return self._time_to

    @time_to.setter
    def time_to(self, time_to):
        """Sets the time_to of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param time_to: The time_to of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: datetime
        """

        self._time_to = time_to

    @property
    def volume(self):
        """Gets the volume of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The volume of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: float
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param volume: The volume of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: float
        """

        self._volume = volume

    @property
    def system_management_action_flag(self):
        """Gets the system_management_action_flag of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The system_management_action_flag of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._system_management_action_flag

    @system_management_action_flag.setter
    def system_management_action_flag(self, system_management_action_flag):
        """Sets the system_management_action_flag of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param system_management_action_flag: The system_management_action_flag of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: str
        """

        self._system_management_action_flag = system_management_action_flag

    @property
    def amendment_flag(self):
        """Gets the amendment_flag of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501


        :return: The amendment_flag of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._amendment_flag

    @amendment_flag.setter
    def amendment_flag(self, amendment_flag):
        """Sets the amendment_flag of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.


        :param amendment_flag: The amendment_flag of this InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow.  # noqa: E501
        :type: str
        """

        self._amendment_flag = amendment_flag

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesMiscDatasetRowsDemandControlInstructionDatasetRow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class TemperatureApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def temperature_get(self, **kwargs):  # noqa: E501
        """Temperature data (TEMP)  # noqa: E501

        This endpoint provides daily average GB temperature data (in Celsius) as well as reference temperatures (low, normal and high).  This average data is calculated by National Grid ESO from the data retrieved from 6 weather stations around Britain.  NGESO use this data as part of the electricity demand forecasting process.                Date parameters must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.temperature_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date _from: The from date for the filter. This must be in the format yyyy-MM-dd.
        :param date to: The to date for the filter. This must be in the format yyyy-MM-dd.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscTemperatureData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.temperature_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.temperature_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def temperature_get_with_http_info(self, **kwargs):  # noqa: E501
        """Temperature data (TEMP)  # noqa: E501

        This endpoint provides daily average GB temperature data (in Celsius) as well as reference temperatures (low, normal and high).  This average data is calculated by National Grid ESO from the data retrieved from 6 weather stations around Britain.  NGESO use this data as part of the electricity demand forecasting process.                Date parameters must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.temperature_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date _from: The from date for the filter. This must be in the format yyyy-MM-dd.
        :param date to: The to date for the filter. This must be in the format yyyy-MM-dd.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscTemperatureData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method temperature_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/temperature', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscTemperatureData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.indicative_imbalance_settlement_api import IndicativeImbalanceSettlementApi  # noqa: E501
from elexonpy.rest import ApiException


class TestIndicativeImbalanceSettlementApi(unittest.TestCase):
    """IndicativeImbalanceSettlementApi unit test stubs"""

    def setUp(self):
        self.api = IndicativeImbalanceSettlementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_get(self):
        """Test case for balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_get

        Acceptance volumes by settlement date (BOAV)  # noqa: E501
        """
        pass

    def test_balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_settlement_period_get(self):
        """Test case for balancing_settlement_acceptance_volumes_all_bid_offer_settlement_date_settlement_period_get

        Acceptance volumes by settlement period (BOAV)  # noqa: E501
        """
        pass

    def test_balancing_settlement_acceptances_all_settlement_date_settlement_period_get(self):
        """Test case for balancing_settlement_acceptances_all_settlement_date_settlement_period_get

        Historic acceptances by settlement period (ISPSTACK, BOALF, BOD)  # noqa: E501
        """
        pass

    def test_balancing_settlement_default_notices_get(self):
        """Test case for balancing_settlement_default_notices_get

        Default notices (CDN)  # noqa: E501
        """
        pass

    def test_balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_get(self):
        """Test case for balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_get

        Indicative period BMU cashflows by settlement date (EBOCF)  # noqa: E501
        """
        pass

    def test_balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_settlement_period_get(self):
        """Test case for balancing_settlement_indicative_cashflows_all_bid_offer_settlement_date_settlement_period_get

        Indicative period BMU cashflows by settlement period (EBOCF)  # noqa: E501
        """
        pass

    def test_balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_get(self):
        """Test case for balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_get

        Indicative volumes by settlement date (DISPTAV)  # noqa: E501
        """
        pass

    def test_balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_settlement_period_get(self):
        """Test case for balancing_settlement_indicative_volumes_all_bid_offer_settlement_date_settlement_period_get

        Indicative volumes by settlement period (DISPTAV)  # noqa: E501
        """
        pass

    def test_balancing_settlement_market_depth_settlement_date_get(self):
        """Test case for balancing_settlement_market_depth_settlement_date_get

        Market depth by settlement date (IMBALNGC, BOD, DISEBSP, DISPTAV)  # noqa: E501
        """
        pass

    def test_balancing_settlement_market_depth_settlement_date_settlement_period_get(self):
        """Test case for balancing_settlement_market_depth_settlement_date_settlement_period_get

        Market depth by settlement period (IMBALNGC, BOD, DISEBSP, DISPTAV)  # noqa: E501
        """
        pass

    def test_balancing_settlement_messages_settlement_date_get(self):
        """Test case for balancing_settlement_messages_settlement_date_get

        Settlement messages by settlement date (SMSG)  # noqa: E501
        """
        pass

    def test_balancing_settlement_messages_settlement_date_settlement_period_get(self):
        """Test case for balancing_settlement_messages_settlement_date_settlement_period_get

        Settlement messages by settlement date and period (SMSG)  # noqa: E501
        """
        pass

    def test_balancing_settlement_stack_all_bid_offer_settlement_date_settlement_period_get(self):
        """Test case for balancing_settlement_stack_all_bid_offer_settlement_date_settlement_period_get

        Settlement bid-offer stacks by settlement period (ISPSTACK)  # noqa: E501
        """
        pass

    def test_balancing_settlement_summary_settlement_date_settlement_period_get(self):
        """Test case for balancing_settlement_summary_settlement_date_settlement_period_get

        Settlement calculation summary (ISPSTACK, DISEBSP, MID, NETBSAD)  # noqa: E501
        """
        pass

    def test_balancing_settlement_system_prices_settlement_date_get(self):
        """Test case for balancing_settlement_system_prices_settlement_date_get

        Settlement system prices by settlement date (DISEBSP)  # noqa: E501
        """
        pass

    def test_balancing_settlement_system_prices_settlement_date_settlement_period_get(self):
        """Test case for balancing_settlement_system_prices_settlement_date_settlement_period_get

        Settlement system prices by settlement date and period (DISEBSP)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
